Module: Sping

Defined in:
lib/sping/version.rb,
lib/sping.rb

Overview

:nodoc:

Defined Under Namespace

Modules: VERSION

Class Method Summary collapse

Class Method Details

.feedsObject

List of feeds under this auth. Must be supplied the global user auth to list feeds.



26
27
# File 'lib/sping.rb', line 26

def feeds
end

.get(key, secret, options = {}) ⇒ Object

This should not require any arguments if a global auth has been set up



21
22
23
# File 'lib/sping.rb', line 21

def get(key, secret, options={})
  Feed.new(key, secret).get(options)
end

.post(key, secret, message) ⇒ Object

This should only require message, if a global auth has been set up



16
17
18
# File 'lib/sping.rb', line 16

def post(key, secret, message)
  Feed.new(key, secret).post(message)
end

.set_user_authObject

Sets up global user auth, if desired. Is thread-safe. Whatever is placed here is available to be used globally but will only work for what they’ve been granted for.



12
13
# File 'lib/sping.rb', line 12

def set_user_auth
end